# Copyright: 2007-2013 Paul Obermeier (obermeier@poSoft.de)
# Distributed under BSD license.

# Call with no parameters to build the CAWT StarKit.
# Call with clean as parameter to remove all intermediate build files.
# Call with fullclean as parameter to remove the StarKit, too.

set optClean ""
if { $argc > 0 } {
    set optClean [lindex $argv 0]
}

set starkitDir [pwd]
set cawtDir    [file join $starkitDir ".."]

set tclkit "tclkit-sh-win32-86.exe"

set auto_path [linsert $auto_path 0 $cawtDir [file join $cawtDir "Externals"]]

set retVal [catch {package require cawt} cawtVersion]

set starkitName      "CawtKit-$cawtVersion"
set starkitVfs       [format "%s.vfs" $starkitName]
set starkitVfsDir    [file join $starkitDir $starkitVfs]
set starkitVfsLibDir [file join $starkitVfsDir "lib"]

file delete -force $starkitName.bat
file delete -force $starkitVfsDir

if { $optClean eq "fullclean" || $optClean eq "" } {
    file delete -force $starkitName.kit
}

if { $optClean ne "" } {
    puts "Cleaned $starkitName.kit and $starkitVfsDir"
    exit 0
}

puts "Generating StarKit $starkitName ..."

file mkdir $starkitVfsDir
file mkdir $starkitVfsLibDir

cd $cawtDir
foreach dir { "CawtCore" "CawtEarth" "CawtExcel" "CawtExplorer" "CawtMatlab" \
              "CawtOcr" "CawtPpt" "CawtWord" } {
    puts "    Copying CAWT package $dir ..."
    file copy [file join $cawtDir $dir] [file join $starkitVfsLibDir $dir]
}
file copy pkgIndex.tcl $starkitVfsLibDir

foreach dir { "base64" "Img" "tablelist" "twapi" } {
    puts "    Copying external package $dir ..."
    file copy [file join $cawtDir "Externals" $dir] [file join $starkitVfsLibDir $dir]
}

cd $starkitDir
file copy main.tcl $starkitVfsDir

puts "Wrapping with $tclkit"
exec $tclkit sdx.kit wrap $starkitName.kit

puts "Done"
