# Test CawtExcel procedures to exchange data between Excel and Matlab files.
#
# Copyright: 2007-2013 Paul Obermeier (obermeier@poSoft.de)
# Distributed under BSD license.

set cawtDir [file join [pwd] ".."]
set auto_path [linsert $auto_path 0 $cawtDir [file join $cawtDir "Externals"]]

package require cawt

set matFile [file join "testIn" "gradient.mat"]

# Open new instance of Excel and add a workbook.
set excelAppId [::Excel::OpenNew]
set workbookId [::Excel::AddWorkbook $excelAppId]

# Delete Excel and Matlab files from previous test run.
file mkdir testOut
set xlsFile [file join [pwd] "testOut" "Excel-12_MatlabFile"]
append xlsFile [::Excel::GetExtString $excelAppId]
file delete -force $xlsFile
set matOutFile1 [file join [pwd] "testOut" "Excel-12_MatlabFile1.mat"]
file delete -force $matOutFile1
set matOutFile2 [file join [pwd] "testOut" "Excel-12_MatlabFile2.mat"]
file delete -force $matOutFile2

# Transfer Matlab data with header information into Excel and vice versa.
set useHeader true

set worksheetId [::Excel::AddWorksheet $workbookId "WithHeader"]

set t1 [clock clicks -milliseconds]
::Excel::MatlabFileToWorksheet $matFile $worksheetId $useHeader
set t2 [clock clicks -milliseconds]
puts "MatlabFileToWorksheet: [expr $t2 - $t1] ms (using header: $useHeader)."

set t1 [clock clicks -milliseconds]
::Excel::WorksheetToMatlabFile $worksheetId $matOutFile1 $useHeader
set t2 [clock clicks -milliseconds]
puts "WorksheetToMatlabFile: [expr $t2 - $t1] ms (using header: $useHeader)."

# Transfer Matlab data without header information into Excel and vice versa.
set useHeader false

set worksheetId [::Excel::AddWorksheet $workbookId "NoHeader"]

set t1 [clock clicks -milliseconds]
::Excel::MatlabFileToWorksheet $matFile $worksheetId $useHeader
set t2 [clock clicks -milliseconds]
puts "MatlabFileToWorksheet: [expr $t2 - $t1] ms (using header: $useHeader)."

set t1 [clock clicks -milliseconds]
::Excel::WorksheetToMatlabFile $worksheetId $matOutFile2 $useHeader
set t2 [clock clicks -milliseconds]
puts "WorksheetToMatlabFile: [expr $t2 - $t1] ms (using header: $useHeader)."

puts "Saving as Excel file: $xlsFile"
::Excel::SaveAs $workbookId $xlsFile

if { [lindex $argv 0] eq "auto" } {
    ::Excel::Quit $excelAppId
    ::Cawt::Destroy
    exit 0
}
::Cawt::Destroy
